@@ -17,7 +17,8 @@ void SPVM_OPCODE_BUILDER_push_opcode_on_exception(
   SPVM_LIST* catch_on_exception_opcode_index_stack,
   SPVM_LIST* return_on_exception_opcode_index_stack,
   SPVM_OP* op_method,
-  int32_t line
+  int32_t line,
+  int32_t no_die
 );
 
 int32_t SPVM_OPCODE_BUILDER_get_typed_var_index(SPVM_COMPILER* compiler, SPVM_OP* op);
