@@ -47,6 +47,8 @@ const char* const* SPVM_BASIC_TYPE_C_ID_NAMES(void) {
     "SPVM",
     "Error::MethodCallNotPermitted",
     "Stringable",
+    "Countable",
+    "CallerInfo",
   };
   
   return id_names;
