@@ -58,7 +58,7 @@ int32_t SPVM__Native__MethodCall__new_method_with_env_stack_common(SPVM_ENV* env
   int32_t is_binary_compatible_stack = env->is_binary_compatible_stack(self_env, self_stack);
   
   if (!is_binary_compatible_stack) {
-    return env->die_v2(env, stack, "The runtime stack $stack is not compatible with the runtime environemnt $env.", __func__, __FILE__, __LINE__);
+    return env->die(env, stack, "The runtime stack $stack is not compatible with the runtime environemnt $env.", __func__, __FILE__, __LINE__);
   }
   
   void* method = NULL;
@@ -67,56 +67,56 @@ int32_t SPVM__Native__MethodCall__new_method_with_env_stack_common(SPVM_ENV* env
   if (method_call_type == 0) {
     
     if (!obj_basic_type_name) {
-      return env->die_v2(env, stack, "The basic type name $basic_type_name must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The basic type name $basic_type_name must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     const char* basic_type_name = env->get_chars(env, stack, obj_basic_type_name);
     
     if (!obj_method_name) {
-      return env->die_v2(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     const char* method_name = env->get_chars(env, stack, obj_method_name);
     
     method = self_env->get_class_method(self_env, self_stack, basic_type_name, method_name);
     if (!method) {
-      return env->die_v2(env, stack, "The \"%s\" class method in the \"%s\" class cannot be found.", __func__, FILE_NAME, __LINE__, method_name, basic_type_name);
+      return env->die(env, stack, "The \"%s\" class method in the \"%s\" class cannot be found.", __func__, FILE_NAME, __LINE__, method_name, basic_type_name);
     }
   }
   else if (method_call_type == 1) {
     
     if (!obj_basic_type_name) {
-      return env->die_v2(env, stack, "The basic type name $basic_type_name must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The basic type name $basic_type_name must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     const char* basic_type_name = env->get_chars(env, stack, obj_basic_type_name);
     
     if (!obj_method_name) {
-      return env->die_v2(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     const char* method_name = env->get_chars(env, stack, obj_method_name);
     
     method = self_env->get_instance_method_static(self_env, self_stack, basic_type_name, method_name);
     if (!method) {
-      return env->die_v2(env, stack, "The \"%s\" instance method in the \"%s\" class cannot be found.", __func__, FILE_NAME, __LINE__, method_name, basic_type_name);
+      return env->die(env, stack, "The \"%s\" instance method in the \"%s\" class cannot be found.", __func__, FILE_NAME, __LINE__, method_name, basic_type_name);
     }
   }
   else if (method_call_type == 2) {
     
     if (!obj_instance) {
-      return env->die_v2(env, stack, "The instance $instance must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The instance $instance must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     if (!obj_method_name) {
-      return env->die_v2(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The method name $method_name must be defined.", __func__, FILE_NAME, __LINE__);
     }
     
     const char* method_name = env->get_chars(env, stack, obj_method_name);
     
     method = self_env->get_instance_method(self_env, self_stack, obj_instance, method_name);
     if (!method) {
-      return env->die_v2(env, stack, "The \"%s\" instance method cannot be found.", __func__, FILE_NAME, __LINE__, method_name);
+      return env->die(env, stack, "The \"%s\" instance method cannot be found.", __func__, FILE_NAME, __LINE__, method_name);
     }
   }
   
@@ -180,7 +180,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
     int32_t error_id_ref_length = env->length(env, stack, obj_error_id_ref);
     
     if (!(error_id_ref_length == 1)) {
-      return env->die_v2(env, stack, "If the reference to an error id $error_id_ref exists, the length of it must be 1.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "If the reference to an error id $error_id_ref exists, the length of it must be 1.", __func__, FILE_NAME, __LINE__);
     }
   }
   
@@ -207,7 +207,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t method_required_args_length = env->api->method->get_required_args_length(runtime, method);
   
   if (!(args_length >= method_required_args_length)) {
-    return env->die_v2(env, stack, "%s#%s method failed to execute. Too few arguments.", __func__, FILE_NAME, __LINE__, class_name, method_name);
+    return env->die(env, stack, "%s#%s method failed to execute. Too few arguments.", __func__, FILE_NAME, __LINE__, class_name, method_name);
   }
   
   int32_t method_args_length = env->api->method->get_args_length(runtime, method);
@@ -253,13 +253,13 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
         );
         
         if (!can_assign) {
-          return env->die_v2(env, stack, "%s#%s method failed to execute. The %dth argument cannot be assigned.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+          return env->die(env, stack, "%s#%s method failed to execute. The %dth argument cannot be assigned.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
         }
         
         int32_t is_binary_compatible_object = self_env->is_binary_compatible_object(self_env, self_stack, obj_arg);
         
         if (!is_binary_compatible_object) {
-          return env->die_v2(env, stack, "%s#%s method failed to execute. The object of the %dth argument is not binary compatible.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+          return env->die(env, stack, "%s#%s method failed to execute. The object of the %dth argument is not binary compatible.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
         }
       }
       
@@ -269,7 +269,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
     }
     else {
       if (!obj_arg) {
-        return env->die_v2(env, stack, "%s#%s method failed to execute. The %dth argument must be defined.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+        return env->die(env, stack, "%s#%s method failed to execute. The %dth argument must be defined.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
       }
       
       int32_t method_arg_type_is_ref = method_arg_type_flag & SPVM_NATIVE_C_TYPE_FLAG_REF;
@@ -279,7 +279,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           switch (method_arg_basic_type_id) {
             case SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Byte", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Byte class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Byte class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int8_t value = env->get_field_byte_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -290,7 +290,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Short", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Short class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Short class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int16_t value = env->get_field_short_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -301,7 +301,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_INT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Int", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Int class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Int class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int32_t value = env->get_field_int_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -312,7 +312,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_LONG : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Long", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Long class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Long class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int64_t value = env->get_field_long_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -323,7 +323,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Float", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Float class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Float class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               float value = env->get_field_float_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -334,7 +334,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "Double", 0)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Double class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the Double class.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               double value = env->get_field_double_by_name(env, stack, obj_arg, "value", &error_id, __func__, FILE_NAME, __LINE__);
@@ -355,7 +355,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           int32_t arg_array_length = env->length(env, stack, obj_arg);
           
           if (!(arg_array_length == method_arg_width)) {
-            return env->die_v2(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be %d.", class_name, method_name, arg_index + 1, method_arg_width, __func__, FILE_NAME, __LINE__);
+            return env->die(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be %d.", class_name, method_name, arg_index + 1, method_arg_width, __func__, FILE_NAME, __LINE__);
           }
           
           void* method_arg_mulnum_field = env->api->basic_type->get_field_by_index(runtime, method_arg_basic_type, 0);
@@ -365,7 +365,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           switch (method_arg_mulnum_field_basic_type_id) {
             case SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "byte", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int8_t* value_ref = env->get_elems_byte(env, stack, obj_arg);
@@ -378,7 +378,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "short", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int16_t* value_ref = env->get_elems_short(env, stack, obj_arg);
@@ -391,7 +391,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_INT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "int", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int32_t* value_ref = env->get_elems_int(env, stack, obj_arg);
@@ -404,7 +404,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_LONG : {
               if (!env->is_type_by_name(env, stack, obj_arg, "long", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int64_t* value_ref = env->get_elems_long(env, stack, obj_arg);
@@ -417,7 +417,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "float", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               float* value_ref = env->get_elems_float(env, stack, obj_arg);
@@ -430,7 +430,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "double", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               double* value_ref = env->get_elems_double(env, stack, obj_arg);
@@ -456,13 +456,13 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           int32_t arg_array_length = env->length(env, stack, obj_arg);
           
           if (!(arg_array_length == 1)) {
-            return env->die_v2(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be 1.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+            return env->die(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be 1.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
           }
           
           switch(method_arg_basic_type_id) {
             case SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "byte", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int8_t* value_ref = env->get_elems_byte(env, stack, obj_arg);
@@ -473,7 +473,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "short", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int16_t* value_ref = env->get_elems_short(env, stack, obj_arg);
@@ -484,7 +484,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_INT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "int", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int32_t* value_ref = env->get_elems_int(env, stack, obj_arg);
@@ -495,7 +495,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_LONG : {
               if (!env->is_type_by_name(env, stack, obj_arg, "long", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int64_t* value_ref = env->get_elems_long(env, stack, obj_arg);
@@ -506,7 +506,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "float", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               float* value_ref = env->get_elems_float(env, stack, obj_arg);
@@ -517,7 +517,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "double", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               double* value_ref = env->get_elems_double(env, stack, obj_arg);
@@ -537,7 +537,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           int32_t arg_array_length = env->length(env, stack, obj_arg);
           
           if (!(arg_array_length == method_arg_width)) {
-            return env->die_v2(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be %d.", class_name, method_name, arg_index + 1, method_arg_width, __func__, FILE_NAME, __LINE__);
+            return env->die(env, stack, "%s#%s method failed to execute. The array length of the %dth argument must be %d.", class_name, method_name, arg_index + 1, method_arg_width, __func__, FILE_NAME, __LINE__);
           }
           
           void* method_arg_mulnum_field = env->api->basic_type->get_field_by_index(runtime, method_arg_basic_type, 0);
@@ -547,7 +547,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
           switch(method_arg_mulnum_field_basic_type_id) {
             case SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "byte", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the byte[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int8_t* value_ref = env->get_elems_byte(env, stack, obj_arg);
@@ -558,7 +558,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "short", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the short[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int16_t* value_ref = env->get_elems_short(env, stack, obj_arg);
@@ -569,7 +569,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_INT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "int", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the int[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int32_t* value_ref = env->get_elems_int(env, stack, obj_arg);
@@ -580,7 +580,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_LONG : {
               if (!env->is_type_by_name(env, stack, obj_arg, "long", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the long[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               int64_t* value_ref = env->get_elems_long(env, stack, obj_arg);
@@ -591,7 +591,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT : {
               if (!env->is_type_by_name(env, stack, obj_arg, "float", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the float[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               float* value_ref = env->get_elems_float(env, stack, obj_arg);
@@ -602,7 +602,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
             }
             case SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE : {
               if (!env->is_type_by_name(env, stack, obj_arg, "double", 1)) {
-                return env->die_v2(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
+                return env->die(env, stack, "%s#%s method failed to execute. The type of the %dth argument must be the double[] type.", __func__, FILE_NAME, __LINE__, class_name, method_name, arg_index + 1);
               }
               
               double* value_ref = env->get_elems_double(env, stack, obj_arg);
@@ -654,7 +654,7 @@ int32_t SPVM__Native__MethodCall__call(SPVM_ENV* env, SPVM_VALUE* stack) {
     int32_t is_binary_compatible_object = env->is_binary_compatible_object(env, stack, self_stack[0].oval);
     
     if (!is_binary_compatible_object) {
-      return env->die_v2(env, stack, "The return object is not binary compatible.", __func__, FILE_NAME, __LINE__);
+      return env->die(env, stack, "The return object is not binary compatible.", __func__, FILE_NAME, __LINE__);
     }
   }
   else {
